==> nextcloud-15.0.5p1.tgz: nextcloud/apps/comments/l10n/de.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "You commented" : "Von Dir kommentiert",
    "%1$s commented" : "%1$s kommentierte",
    "{author} commented" : "{author} kommentierte",
    "You commented on %1$s" : "Du hast %1$s kommentiert",
    "You commented on {file}" : "Du hast {file} kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentierte %2$s",
    "{author} commented on {file}" : "{author} hat {file} kommentiert",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du wurdest in einem Kommentar auf \"{file}\" von einem bereits gelöschten Nutzer erwähnt",
    "{user} mentioned you in a comment on “{file}”" : "{user} hat Dich in einem Kommentar zu “{file}” erwähnt ",
    "Files app plugin to add comments to files" : "Ein Plugin für die Dateien-App zum Kommentieren von Dateien",
    "Edit comment" : "Kommentar bearbeiten",
    "Delete comment" : "Kommentar löschen",
    "New comment …" : "Neuer Kommentar …",
    "Post" : "Speichern",
    "Cancel" : "Abbrechen",
    "[Deleted user]" : "[Gelöschter Benutzer]",
    "No comments yet, start the conversation!" : "Keine Kommentare bisher. Beginne die Diskussion!",
    "More comments …" : "Weitere Kommentare…",
    "Save" : "Speichern",
    "Allowed characters {count} of {max}" : "Erlaubte Zeichen {count} von {max}",
    "Error occurred while retrieving comment with ID {id}" : "Es ist ein Fehler beim Empfangen des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while updating comment with id {id}" : "Es ist ein Fehler beim Aktualisieren des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while posting comment" : "Es ist ein Fehler beim Veröffentlichen des Kommentars aufgetreten",
    "_%n unread comment_::_%n unread comments_" : ["%n ungelesener Kommentar","%n ungelesene Kommentare"],
    "Comment" : "Kommentar",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Du wurdest in einem Kommentar auf \"%s\" von einem bereits gelöschten Nutzer erwähnt",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s hat Dich in einem Kommentar zu “%2$s” erwähnt "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/comments/l10n/de.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "You commented" : "Von Dir kommentiert",
    "%1$s commented" : "%1$s kommentierte",
    "{author} commented" : "{author} kommentierte",
    "You commented on %1$s" : "Du hast %1$s kommentiert",
    "You commented on {file}" : "Du hast {file} kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentierte %2$s",
    "{author} commented on {file}" : "{author} hat {file} kommentiert",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Du wurdest in einem Kommentar auf \"{file}\" von einem bereits gelöschten Benutzer erwähnt",
    "{user} mentioned you in a comment on “{file}”" : "{user} hat Dich in einem Kommentar zu “{file}” erwähnt ",
    "Files app plugin to add comments to files" : "Ein Plugin für die Dateien-App zum Kommentieren von Dateien",
    "Edit comment" : "Kommentar bearbeiten",
    "Delete comment" : "Kommentar löschen",
    "New comment …" : "Neuer Kommentar …",
    "Post" : "Speichern",
    "Cancel" : "Abbrechen",
    "[Deleted user]" : "[Gelöschter Benutzer]",
    "No comments yet, start the conversation!" : "Keine Kommentare bisher. Beginne die Diskussion!",
    "More comments …" : "Weitere Kommentare…",
    "Save" : "Speichern",
    "Allowed characters {count} of {max}" : "Erlaubte Zeichen {count} von {max}",
    "Error occurred while retrieving comment with ID {id}" : "Es ist ein Fehler beim Empfangen des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while updating comment with id {id}" : "Es ist ein Fehler beim Aktualisieren des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while posting comment" : "Es ist ein Fehler beim Veröffentlichen des Kommentars aufgetreten",
    "_%n unread comment_::_%n unread comments_" : ["%n ungelesener Kommentar","%n ungelesene Kommentare"],
    "_1 new comment_::_{unread} new comments_" : ["1 neuer Kommentar","[unread] neue Kommentare"],
    "Comment" : "Kommentar"
},
"nplurals=2; plural=(n != 1);");
